=======
History
=======



0.1.3 (2021-04-21)
------------------

* Minor release.

This is a minor update to fix a couple of small errors in doc strings.
It also adds unit testing for updating the underlying data.



0.1.2 (2021-04-21)
------------------

* Minor release.

This version achieves the basic task at hand. It does not yet have full testing.



0.1.1 (2021-04-21)
------------------

* Minor release.

This version has been yanked.



0.1.0 (2021-04-21)
------------------

* First release on PyPI.

This version has been yanked.






